# FileScape

fileScape is a simple and customizable file organization tool. It helps you sort and manage files efficiently based on size, type, extenison, etc.

## Roadmap

- [ ] Add more sorting options (date, size, etc)
- [ ] Create CLI commands


<!-- ## Features

* Organize files by size, type, or custom rules.
* Move, rename, or delete empty directories after sorting.
* Simple CLI interface for easy use.
* Lightweight and efficient.

## Installation

You can install fileScape via pip:

```pip install fileScape```

Usage

Run the following command to organize files in a directory:

```filescape --path /your/directory --mode size```

### Options:

* `--path`: Specify the directory to organize.
* `--mode`: Choose organization mode (size, type, custom). -->


## Contributing

I’d love feedback on useful features to add! Feel free to open issues or submit pull requests.